/**
 * Generated by Apache Royale Compiler from org/apache/royale/test/Assert.as
 * org.apache.royale.test.Assert
 *
 * @fileoverview
 *
 * @suppress {checkTypes|accessControls}
 */

goog.provide('org.apache.royale.test.Assert');

goog.require('org.apache.royale.test.AssertionError');



/**
 * @constructor
 */
org.apache.royale.test.Assert = function() {
};


/**
 * Prevent renaming of class. Needed for reflection.
 */
goog.exportSymbol('org.apache.royale.test.Assert', org.apache.royale.test.Assert);


/**
 * Asserts that the provided values are strictly equal (equivalent to
 * the <code>===</code> operator).
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotStrictlyEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are not strictly equal (equivalent
 * to the <code>!==</code> operator).
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failStrictlyEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are loosely equal (equivalent to
 * the <code>==</code> operator).
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotEquals(actual, expected, message);
};


/**
 * Asserts that the provided values are not loosely equal (equivalent to
 * the <code>!=</code> operator).
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failEquals(actual, expected, message);
};


/**
 * Asserts that the provided value is true (equivalent to testing the
 * value in an <code>if(value)</code> statement).
 * @export
 * @param {*} value
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertTrue = function(value, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failFalse(value, message);
};


/**
 * Asserts that the provided value is true (equivalent to testing the
 * value in an <code>if(!value)</code> statement).
 * @export
 * @param {*} value
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertFalse = function(value, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failTrue(value, message);
};


/**
 * Asserts that the provided value is null.
 * @export
 * @param {*} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNull = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNotNull(actual, message);
};


/**
 * Asserts that the provided value is not null.
 * @export
 * @param {*} actual
 * @param {string=} message
 */
org.apache.royale.test.Assert.assertNotNull = function(actual, message) {
  message = typeof message !== 'undefined' ? message : null;
  org.apache.royale.test.Assert.failNull(actual, message);
};


/**
 * Fails.
 * @export
 * @param {string=} message
 * @param {Error=} sourceError
 */
org.apache.royale.test.Assert.fail = function(message, sourceError) {
  message = typeof message !== 'undefined' ? message : "";
  sourceError = typeof sourceError !== 'undefined' ? sourceError : null;
  throw new org.apache.royale.test.AssertionError(message, sourceError);
};


/**
 * Fails if the condition is true.
 * @export
 * @param {*} condition
 * @param {string=} message
 */
org.apache.royale.test.Assert.failTrue = function(condition, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (condition) {
    org.apache.royale.test.Assert.failWithUserMessage("expected false but was true", message);
  }
};


/**
 * Fails if the condition is false.
 * @export
 * @param {*} condition
 * @param {string=} message
 */
org.apache.royale.test.Assert.failFalse = function(condition, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (!condition) {
    org.apache.royale.test.Assert.failWithUserMessage("expected true but was false", message);
  }
};


/**
 * Fails if the values are loosely equal.
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual == expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> not to be equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are not loosely equal.
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual != expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to be equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are strictly equal.
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual === expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> not to be strictly equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the values are not strictly equal.
 * @export
 * @param {*} actual
 * @param {*} expected
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotStrictlyEquals = function(actual, expected, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (actual !== expected) {
    org.apache.royale.test.Assert.failWithUserMessage("expected <" + actual + "> to be strictly equal to <" + expected + ">", message);
  }
};


/**
 * Fails if the value is null.
 * @export
 * @param {*} object
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNull = function(object, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (object == null) {
    org.apache.royale.test.Assert.failWithUserMessage("expected not null", message);
  }
};


/**
 * Fails if the value is not null.
 * @export
 * @param {*} object
 * @param {string=} message
 */
org.apache.royale.test.Assert.failNotNull = function(object, message) {
  message = typeof message !== 'undefined' ? message : null;
  if (object != null) {
    org.apache.royale.test.Assert.failWithUserMessage("expected null: <" + object + ">", message);
  }
};


/**
 * @asprivate
 * @protected
 * @param {string} userMessage
 * @param {string=} failMessage
 */
org.apache.royale.test.Assert.failWithUserMessage = function(userMessage, failMessage) {
  failMessage = typeof failMessage !== 'undefined' ? failMessage : null;
  if (failMessage) {
    throw new org.apache.royale.test.AssertionError(userMessage + " - " + failMessage);
  }
  throw new org.apache.royale.test.AssertionError(userMessage);
};


/**
 * Metadata
 *
 * @type {Object.<string, Array.<Object>>}
 */
org.apache.royale.test.Assert.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'Assert', qName: 'org.apache.royale.test.Assert', kind: 'class' }] };



/**
 * Reflection
 *
 * @return {Object.<string, Function>}
 */
org.apache.royale.test.Assert.prototype.ROYALE_REFLECTION_INFO = function () {
  return {
    methods: function () {
      return {
        '|assertStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertNotStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertNotEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|assertTrue': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertFalse': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|assertNotNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|fail': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ 'String', true ,'Error', true ]; }},
        '|failTrue': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failFalse': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNotEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNotStrictlyEquals': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'*', false ,'String', true ]; }},
        '|failNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }},
        '|failNotNull': { type: 'void', declaredBy: 'org.apache.royale.test.Assert', parameters: function () { return [ '*', false ,'String', true ]; }}
      };
    }
  };
};
/**
 * @const
 * @type {number}
 */
org.apache.royale.test.Assert.prototype.ROYALE_COMPILE_FLAGS = 10;