/**
 * Generated by Apache Royale Compiler from org/apache/royale/test/async/Async.as
 * org.apache.royale.test.async.Async
 *
 * @fileoverview
 *
 * @suppress {checkTypes|accessControls}
 */

goog.provide('org.apache.royale.test.async.Async');

goog.require('org.apache.royale.events.Event');
goog.require('org.apache.royale.events.EventDispatcher');
goog.require('org.apache.royale.test.Assert');
goog.require('org.apache.royale.test.async.AsyncLocator');
goog.require('org.apache.royale.test.async.IAsyncHandler');



/**
 * @constructor
 */
org.apache.royale.test.async.Async = function() {
};


/**
 * Prevent renaming of class. Needed for reflection.
 */
goog.exportSymbol('org.apache.royale.test.async.Async', org.apache.royale.test.async.Async);


/**
 * Calls a function after a delay, measured in milliseconds.
 * @export
 * @param {Object} testCase
 * @param {Function} delayedFunction
 * @param {number} delayMS
 */
org.apache.royale.test.async.Async.delayCall = function(testCase, delayedFunction, delayMS) {
  var /** @type {org.apache.royale.test.async.IAsyncHandler} */ handler = org.apache.royale.test.async.AsyncLocator.getAsyncHandlerForTest(testCase);
  handler.asyncHandler(function() {
    delayedFunction();
  }, delayMS);
};


/**
 * If an event is not dispatched within the specified delay (measured in
 * milliseconds), the test will fail.
 * @export
 * @param {Object} testCase
 * @param {org.apache.royale.events.EventDispatcher} dispatcher
 * @param {string} eventName
 * @param {number} timeout
 */
org.apache.royale.test.async.Async.requireEvent = function(testCase, dispatcher, eventName, timeout) {
  org.apache.royale.test.async.Async.handleEvent(testCase, dispatcher, eventName, null, timeout);
};


/**
 * Similar to <code>requireEvent()</code>, requires an event to be
 * dispatched for the test to pass, but the arguments are also passed to
 * a custom event handler that may perform additional checks.
 * @export
 * @param {Object} testCase
 * @param {org.apache.royale.events.EventDispatcher} dispatcher
 * @param {string} eventName
 * @param {Function} eventHandler
 * @param {number} timeout
 */
org.apache.royale.test.async.Async.handleEvent = function(testCase, dispatcher, eventName, eventHandler, timeout) {
  function handleDispatch(rest) {
    rest = Array.prototype.slice.call(arguments, 0);
    eventDispatched = true;
    if (eventHandler != null) {
      eventHandler.apply(null, rest);
    }
  };
  var /** @type {boolean} */ eventDispatched = false;
  dispatcher.addEventListener(eventName, handleDispatch);
  var /** @type {org.apache.royale.test.async.IAsyncHandler} */ handler = org.apache.royale.test.async.AsyncLocator.getAsyncHandlerForTest(testCase);
  handler.asyncHandler(function() {
    dispatcher.removeEventListener(eventName, handleDispatch);
    if (!eventDispatched) {
      org.apache.royale.test.Assert.fail("Timeout occurred before expected event: " + eventName);
    }
  }, timeout);
};


/**
 * If an event is dispatched within the specified delay, the test case
 * will fail.
 * @export
 * @param {Object} testCase
 * @param {org.apache.royale.events.EventDispatcher} dispatcher
 * @param {string} eventName
 * @param {number} timeout
 */
org.apache.royale.test.async.Async.failOnEvent = function(testCase, dispatcher, eventName, timeout) {
  function handleDispatch(event, rest) {
    rest = Array.prototype.slice.call(arguments, 1);
    savedEvent = event;
    eventDispatched = true;
  };
  var /** @type {org.apache.royale.events.Event} */ savedEvent = null;
  var /** @type {boolean} */ eventDispatched = false;
  dispatcher.addEventListener(eventName, handleDispatch);
  var /** @type {org.apache.royale.test.async.IAsyncHandler} */ handler = org.apache.royale.test.async.AsyncLocator.getAsyncHandlerForTest(testCase);
  handler.asyncHandler(function() {
    dispatcher.removeEventListener(eventName, handleDispatch);
    if (eventDispatched) {
      var /** @type {string} */ message = "Unexpected event " + eventName + "dispatched";
      if (savedEvent != null) {
        message += " " + String(savedEvent);
      }
      org.apache.royale.test.Assert.fail(message);
    }
  }, timeout);
};


/**
 * Metadata
 *
 * @type {Object.<string, Array.<Object>>}
 */
org.apache.royale.test.async.Async.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'Async', qName: 'org.apache.royale.test.async.Async', kind: 'class' }] };



/**
 * Reflection
 *
 * @return {Object.<string, Function>}
 */
org.apache.royale.test.async.Async.prototype.ROYALE_REFLECTION_INFO = function () {
  return {
    methods: function () {
      return {
        '|delayCall': { type: 'void', declaredBy: 'org.apache.royale.test.async.Async', parameters: function () { return [ 'Object', false ,'Function', false ,'int', false ]; }},
        '|requireEvent': { type: 'void', declaredBy: 'org.apache.royale.test.async.Async', parameters: function () { return [ 'Object', false ,'org.apache.royale.events.EventDispatcher', false ,'String', false ,'int', false ]; }},
        '|handleEvent': { type: 'void', declaredBy: 'org.apache.royale.test.async.Async', parameters: function () { return [ 'Object', false ,'org.apache.royale.events.EventDispatcher', false ,'String', false ,'Function', false ,'int', false ]; }},
        '|failOnEvent': { type: 'void', declaredBy: 'org.apache.royale.test.async.Async', parameters: function () { return [ 'Object', false ,'org.apache.royale.events.EventDispatcher', false ,'String', false ,'int', false ]; }}
      };
    }
  };
};
/**
 * @const
 * @type {number}
 */
org.apache.royale.test.async.Async.prototype.ROYALE_COMPILE_FLAGS = 10;